@@ -748,6 +748,11 @@ class FuzzyKeyDict(_FuzzyDictBase):
 
     Pickling seems to work but I would use this with caution.
 
+    TODO: consider desired behavior for comparing dict and FuzzyKeyDict with
+    the same keys/values. Currently return equal but I could see an argument
+    for either way, given that their type's behavior is rather different but
+    this is still a subclass of dict.
+
     Examples
     --------
     d = FuzzyKeyDict(limit=3)
@@ -874,7 +879,8 @@ class PriorityQueue:
                 self.put(item, priority)
 
     def put(self, item, priority):
-        heappush(self._items, (priority, item))
+        # Negate priority because package only provides min heap.
+        heappush(self._items, (-priority, item))
 
     def pop(self):
         try:
@@ -1059,14 +1065,14 @@ class Results:
     def from_dict(cls, data):
         return cls(**data)
 
-    def from_dict(cls, data):
-        return cls(**data)
-
     def __repr__(self):
         arg_strs = ", ".join(f'{k}={v!r}' for k, v in self.items())
         return f'{type(self).__name__}({arg_strs})'
 
     def __iter__(self):
+        """Unlike dict, iterate over values because this is still closer to a
+        tuple at heart. Keys are honestly more like documentation here.
+        """
         yield from self.values()
 
     def __len__(self):
